@@ -63,7 +63,7 @@ class Pound(object):
         vars['backends'] = []
         for l in self.options['backends'].split("\n"):
             l = l.strip()
-            if l: vars['backends'].append(dict(zip['address', 'port'], l.split(":", 1)))
+            if l: vars['backends'].append(dict(zip(['address', 'port'], l.split(":", 1))))
         if not os.path.exists(outputdir):
             os.mkdir(outputdir)
         template = open(self.template).read()
